@@ -55,7 +55,7 @@ static gint y_flag_start;
 #define SOUNDLISTFILE PACKAGE
 
 static gchar *linguas[] = {
-  "",			N_("Your system default"),
+  "",			N_("Language: your system default"),
   "af_ZA.UTF-8",	N_("Afrikaans"),
   "sq_AL.UTF-8",	N_("Albanian"),
   "am_ET.UTF-8",	N_("Amharic"),
@@ -90,6 +90,7 @@ static gchar *linguas[] = {
   "ja_JP.UTF-8",	N_("Japanese"),
   "rw_RW.UTF-8",	N_("Kinyarwanda"),
   "ko_KR.UTF-8",	N_("Korean"),
+  "lv_LV.UTF-8",	N_("Latvian"),
   "lt_LT.UTF-8",	N_("Lithuanian"),
   "mk_MK.UTF-8",	N_("Macedonian"),
   "ms_MY.UTF-8",	N_("Malay"),
@@ -127,10 +128,10 @@ static gchar *linguas[] = {
 };
 
 static gchar *timername[] = {
-  N_("No time limit"),
-  N_("Slow timer"),
-  N_("Normal timer"),
-  N_("Fast timer")
+  N_("Timer: No time limit"),
+  N_("Timer: Slow timer"),
+  N_("Timer: Normal timer"),
+  N_("Timer: Fast timer")
 };
 
 static gchar *filtername =
@@ -499,7 +500,7 @@ gc_locale_get_name(const gchar *locale_code)
   if ( !locale )
     return NULL;
 
-  if( !g_ascii_strncasecmp(locale, "C", 1) )
+  if( !g_ascii_strcasecmp(locale, "C") )
       locale = GC_DEFAULT_LOCALE;
 
   /*
