@@ -23,6 +23,7 @@
 #include <unistd.h>
 #include <time.h>
 #include <string.h>
+#include <stdlib.h>
 
 #ifdef WIN32
 // WIN32
@@ -37,7 +38,7 @@
 
 // Include Mac OS X menu synchronization on native OSX build
 #ifdef  MAC_INTEGRATION
-#include "ige-mac-menu.h"
+#include "gtk-mac-menu.h"
 #endif
 
 #include <glib/gstdio.h>
@@ -142,9 +143,6 @@ static gint  popt_no_quit	   = FALSE;
 static gint  popt_no_config        = FALSE;
 static gint  popt_no_level         = FALSE;
 static gint  popt_no_database      = FALSE;
-static gchar *popt_server          = NULL;
-static gint  *popt_web_only        = NULL;
-static gchar *popt_cache_dir       = NULL;
 static gchar *popt_drag_mode       = NULL;
 static gint popt_no_zoom           = FALSE;
 static gint popt_test              = FALSE;
@@ -182,7 +180,7 @@ static GOptionEntry options[] = {
   {"root-menu", 'l', 0, G_OPTION_ARG_STRING, &popt_root_menu,
    N_("Run GCompris with local menu"
       " (e.g -l /reading will let you play only activities in the reading directory, -l /strategy/connect4 only the connect4 activity)."
-      " Use '-l list' to list all the availaible activities and their descriptions."), NULL},
+      " Use '-l list' to list all the available activities and their descriptions."), NULL},
 
   {"package_data_dir", 'A', 0, G_OPTION_ARG_STRING, &popt_package_data_dir,
    N_("GCompris will find the data dir in this directory"), NULL},
@@ -194,7 +192,7 @@ static GOptionEntry options[] = {
    N_("GCompris will find the activity plugins in this directory"), NULL},
 
   {"python_plugin_dir", 'P', 0, G_OPTION_ARG_STRING, &popt_python_plugin_dir,
-   N_("GCompris will find the python activity in this directory"), NULL},
+   N_("GCompris will find the Python activity in this directory"), NULL},
 
   {"locale_dir", '\0', 0, G_OPTION_ARG_STRING, &popt_locale_dir,
    N_("GCompris will find the locale file (.mo translation) in this directory"), NULL},
@@ -241,16 +239,6 @@ static GOptionEntry options[] = {
   {"disable-database",'\0', 0, G_OPTION_ARG_NONE, &popt_no_database,
    N_("Disable the database (slower start and no user log)"), NULL},
 
-  {"server", '\0', 0, G_OPTION_ARG_STRING, &popt_server,
-   N_("GCompris will get images, sounds and activity data from this server if not found locally."), NULL},
-
-  {"web-only", '\0', 0, G_OPTION_ARG_NONE, &popt_web_only,
-   N_("Only when --server is provided, disable check for local resource first."
-      " Data are always taken from the web server."), NULL},
-
-  {"cache-dir", '\0', 0, G_OPTION_ARG_STRING, &popt_cache_dir,
-   N_("In server mode, specify the cache directory used to avoid useless downloads."), NULL},
-
   {"drag-mode", 'g', 0, G_OPTION_ARG_STRING, &popt_drag_mode,
    N_("Global drag and drop mode: normal, 2clicks, both. Default mode is normal."), NULL},
 
@@ -760,7 +748,7 @@ init_workspace()
 #ifdef MAC_INTEGRATION
   GtkWidget *quit_item;
   quit_item = gtk_menu_item_new();
-  ige_mac_menu_set_quit_menu_item(GTK_MENU_ITEM (quit_item));
+  gtk_mac_menu_set_quit_menu_item(GTK_MENU_ITEM (quit_item));
   g_signal_connect(GTK_OBJECT (quit_item),
 		   "activate", G_CALLBACK (quit_cb), NULL);
   gtk_widget_show (quit_item);
@@ -1201,8 +1189,6 @@ static void cleanup()
   sugar_cleanup();
   gc_fullscreen_set(FALSE);
   gc_menu_destroy();
-  gc_net_destroy();
-  gc_cache_destroy();
   gc_prop_destroy(gc_prop_get());
 }
 
@@ -1317,9 +1303,7 @@ static void load_properties ()
   /* Initialize the binary relocation API
    *  http://autopackage.org/docs/binreloc/
    */
-  if(gbr_init (&error))
-    g_message("Binary relocation enabled");
-  else
+  if( ! gbr_init (&error))
     {
       if (error->code == GBR_INIT_ERROR_DISABLED)
 	g_message("Binary relocation disabled");
@@ -1328,9 +1312,6 @@ static void load_properties ()
       g_error_free (error);
     }
 
-  exec_prefix = gbr_find_exe_dir(NULL);
-  g_warning("exec_prefix %s\n", (exec_prefix==NULL ? "NONE" : exec_prefix));
-
   {
     gchar *pkg_data_dir = gbr_find_data_dir(PACKAGE_DATA_DIR);
     gchar *pkg_clib_dir = gbr_find_lib_dir(PACKAGE_CLIB_DIR);
@@ -1346,8 +1327,14 @@ static void load_properties ()
     g_free(pkg_data_dir);
     g_free(pkg_clib_dir);
   }
+}
+
+/* Display the directory value we have */
+static void display_property_dirs()
+{
+  exec_prefix = gbr_find_exe_dir(NULL);
+  printf("exec_prefix              = %s\n", (exec_prefix==NULL ? "NONE" : exec_prefix));
 
-  /* Display the directory value we have */
   printf("package_data_dir         = %s\n", properties->package_data_dir);
   printf("package_skin_dir         = %s\n", properties->package_skin_dir);
   printf("package_menu_dir         = %s\n", properties->menu_dir);
@@ -1640,12 +1627,22 @@ main (int argc, char *argv[])
   sugar_setup(&argc, &argv);
 
   /* Argument parsing */
-  context = g_option_context_new("GCompris");
+  context = g_option_context_new(" - An educational software for chilren 2 to 10");
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
   g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free(context);
 
+  if (popt_version)
+    {
+      printf (_("GCompris\nVersion: %s\nLicense: GPL\n"
+		"More info at http://gcompris.net\n"),
+	      VERSION);
+      exit (0);
+    }
+
+  display_property_dirs();
+
   /* Set the default message handler, it avoids message with option -D */
   g_log_set_handler (NULL, G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_WARNING | G_LOG_LEVEL_DEBUG | G_LOG_FLAG_FATAL
 		     | G_LOG_FLAG_RECURSION, gc_log_handler, NULL);
@@ -1703,14 +1700,6 @@ main (int argc, char *argv[])
   gc_locale_set(properties->locale);
 #endif
 
-  if (popt_version)
-    {
-      printf (_("GCompris\nVersion: %s\nLicence: GPL\n"
-		"More info at http://gcompris.net\n"),
-	      VERSION);
-      exit (0);
-    }
-
   if (popt_fullscreen)
     {
       properties->fullscreen = TRUE;
@@ -1953,33 +1942,6 @@ main (int argc, char *argv[])
       properties->reread_menu = TRUE;
   }
 
-  if (popt_server){
-#ifdef USE_GNET
-      properties->server = g_strdup(popt_server);
-      printf("   Server '%s'\n", properties->server);
-#else
-      printf(_("The --server option cannot be used because"
-	       " GCompris has been compiled without network support!"));
-      exit(1);
-#endif
-  }
-
-  if(popt_web_only) {
-    g_free(properties->package_data_dir);
-    properties->package_data_dir = g_strdup("");
-
-    g_free(properties->system_icon_dir);
-    properties->system_icon_dir = g_strdup("");
-  }
-
-  if (popt_server){
-    if(popt_cache_dir)
-      properties->cache_dir = g_strdup(popt_cache_dir);
-    else
-      properties->cache_dir = g_build_filename(g_get_user_cache_dir(), "gcompris", NULL);
-    printf("   Cache dir '%s'\n",properties->cache_dir);
-  }
-
   if (popt_drag_mode){
     if (strcmp(popt_drag_mode, "default") == 0)
       properties->drag_mode = GC_DRAG_MODE_GRAB;
@@ -2051,10 +2013,6 @@ main (int argc, char *argv[])
 
   single_instance_check();
 
-  /* networking init */
-  gc_net_init();
-  gc_cache_init();
-
   gc_sound_build_music_list();
 
   if(properties->music || properties->fx)
