@@ -28,6 +28,9 @@
 #include "gcompris.h"
 #include "status.h"
 
+#define IS_ADMIN(board) ( ( strncmp(board->section, "/administration", \
+				   strlen("/administration")) == 0 ) )
+
 static GcomprisBoard *gc_menu_load_board(const gchar*, const gchar*, gboolean);
 
 GcomprisBoard	*_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname, gboolean db);
@@ -354,10 +357,19 @@ gc_menu_section_get(gchar *section)
   return NULL;
 }
 
+/**
+ * Sort by difficulty and then by name
+ */
 static int
 boardlist_compare_func(const void *a, const void *b)
 {
-  return strcasecmp(((GcomprisBoard *) a)->difficulty, ((GcomprisBoard *) b)->difficulty);
+  int diff_cmp = strcasecmp(((GcomprisBoard *) a)->difficulty,
+			    ((GcomprisBoard *) b)->difficulty);
+  if ( diff_cmp == 0 )
+    return strcasecmp(((GcomprisBoard *) a)->name,
+		      ((GcomprisBoard *) b)->name);
+  else
+    return diff_cmp;
 }
 
 /** Return true is there are at least one activity in the given section
@@ -551,8 +563,12 @@ void gc_menu_load_dir(char *dirname, gboolean db){
       /* add the board to the list */
       GcomprisBoard *board = gc_menu_load_board(dirname, one_dirent, db);
       if (board) {
-        board->board_id = new_board_id++;
-	    list_old_boards_id = suppress_int_from_list(list_old_boards_id, board->board_id);
+	if ( ! board->board_id )
+	  // If there is no datadase, let's give an id here
+	  board->board_id = new_board_id++;
+
+	if ( ! IS_ADMIN(board) )
+	  list_old_boards_id = suppress_int_from_list(list_old_boards_id, board->board_id);
       }
     }
   }
@@ -600,9 +616,7 @@ static GcomprisBoard *gc_menu_load_board(const gchar *dirname,
 	  if (properties->administration)
 	    boards_list = g_list_append(boards_list, board_read);
 	  else {
-	    if ((strncmp(board_read->section,
-			 "/administration",
-			 strlen("/administration"))!=0)) {
+	    if ( ! IS_ADMIN(board_read) ) {
 	      boards_list = g_list_append(boards_list, board_read);
 	    }
 	    else
